# frozen_string_literal: true

require 'dadatas/api_call'

module Dadatas
  # Suggestion API
  class Suggestion
    BASE_URL = 'https://suggestions.dadata.ru/suggestions/api/4_1/rs/'

    attr_reader :config

    def initialize(config)
      @config = config
    end

    def organization(query: nil)
      call_method('suggest/party', query: query)
    end

    def address_by_fias_id(fias_id: nil)
      call_method('findById/address', query: fias_id)
    end

    def address_by_str(query: nil)
      call_method('suggest/address', query: query)
    end

    def bank(query: nil)
      call_method('findById/bank', query: query)
    end

    def bank_branch(query: nil, kpp: nil)
      call_method('findById/bank', query: query, kpp: kpp)
    end

    private

    def call_method(method, **query_data)
      Dadatas::ApiCall.new(
        URI(URI.join(BASE_URL, method)),
        config,
        query_data
      ).call
    end
  end
end
